#! /bin/sh
# -*- mode: sh; coding: utf-8 -*-
#
# Run this to generate all the initial makefiles, etc.
#

PKG_NAME="PySysInfo"

srcdir=$(dirname $0)
NO_AUTOMAKE=0

(autoconf --version) < /dev/null > /dev/null 2>&1 || {
    echo
    echo "**Error**: Missing 'autoconf'."
    echo "You must have 'autoconf 2.60' or later installed."
    echo "Download the appropriate package for your distribution,"
    echo "or get the source tarball at ftp://ftp.gnu.org/pub/gnu/autoconf/"
    exit 1
}

(automake --version) < /dev/null > /dev/null 2>&1 || {
    echo
    echo "**Error**: Missing 'automake'."
    NO_AUTOMAKE=1
}

# if no automake, don't bother testing for aclocal
test "$NO_AUTOMAKE" -eq 1 || (aclocal --version) < /dev/null > /dev/null 2>&1 || {
    echo
    echo "**Error**: Missing 'aclocal'.  The version of 'automake'"
    echo "installed doesn't appear recent enough."
    NO_AUTOMAKE=1
}

if test "$NO_AUTOMAKE" -eq 1; then
    echo "You must have 'automake 1.10' or later installed."
    echo "Download the appropriate package for your distribution,"
    echo "or get the source tarball at ftp://ftp.gnu.org/pub/gnu/automake/"
    exit 1
fi

if test -z "$*"; then
    echo "**Warning**: I am going to run 'configure' with no arguments."
    echo "If you wish to pass any to it, please specify them on the"
    echo \'$0\'" command line."
    echo
fi

(
    cd $srcdir
    echo "Running aclocal..."
    aclocal
    echo "Running automake..."
    automake --add-missing
    echo "Running autoconf..."
    autoconf
)

if test x$NOCONFIGURE = x; then
  echo Running $srcdir/configure $conf_flags "$@" ...
  $srcdir/configure $conf_flags "$@" \
  && echo Now type \'make\' to compile $PKG_NAME
else
  echo Skipping configure process.
fi

exit 0
